==> haskell-aeson-1.4.0.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson
version: 1.4.0.0
id: aeson-1.4.0.0-AHCyj8zfDAH4OWvdHNQ6e4
key: aeson-1.4.0.0-AHCyj8zfDAH4OWvdHNQ6e4
license: BSD-3-Clause
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.
    .
    To get started, see the documentation for the @Data.Aeson@ module
    below.
    .
    (A note on naming: in Greek mythology, Aeson was the father of Jason.)
category: Text, Web, JSON
abi: fdab1040117f76e54abdbd478f25341d
exposed: True
exposed-modules:
    Data.Aeson Data.Aeson.Encode Data.Aeson.Encoding
    Data.Aeson.Encoding.Internal Data.Aeson.Internal
    Data.Aeson.Internal.Time Data.Aeson.Parser
    Data.Aeson.Parser.Internal Data.Aeson.TH Data.Aeson.Text
    Data.Aeson.Types
hidden-modules: Data.Aeson.Compat Data.Aeson.Encoding.Builder
                Data.Aeson.Internal.Functions Data.Aeson.Parser.Unescape
                Data.Aeson.Parser.Time Data.Aeson.Types.FromJSON
                Data.Aeson.Types.Generic Data.Aeson.Types.ToJSON
                Data.Aeson.Types.Class Data.Aeson.Types.Internal
                Data.Attoparsec.Time Data.Attoparsec.Time.Internal
                Data.Aeson.Parser.UnescapePure
import-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-1.4.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-1.4.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/aeson-1.4.0.0
hs-libraries: HSaeson-1.4.0.0-AHCyj8zfDAH4OWvdHNQ6e4
depends:
    attoparsec-0.13.2.2-KQfUWPhYfGY7y53JEXSJuZ base-4.11.1.0
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ containers-0.5.11.0
    deepseq-1.4.3.0 dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD
    ghc-prim-0.5.2.0 hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO template-haskell-2.13.0.0
    text-1.2.3.0 th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88
    time-1.8.0.2 time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq bytestring-0.10.8.2
abi-depends: attoparsec-0.13.2.2-KQfUWPhYfGY7y53JEXSJuZ=5fc61cc528c94bde8145f6cbd8ed3b00
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=fc280138c1e1b70cf939493d29d4c902
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=d8185cdeb1f72c3606ef0c9fb78dc6d0
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=303b2de9b3dc2b2e86b6ff0f8de41846
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb=f41790414214237de89461384d016ee3
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71=b4d53b96ebd09e78eeddd19077455aea
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
haddock-interfaces: /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html: /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-1.4.0.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson
version: 1.4.0.0
id: aeson-1.4.0.0-LGp6kTtgO3W1vagljwPVLq
key: aeson-1.4.0.0-LGp6kTtgO3W1vagljwPVLq
license: BSD-3-Clause
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.
    .
    To get started, see the documentation for the @Data.Aeson@ module
    below.
    .
    (A note on naming: in Greek mythology, Aeson was the father of Jason.)
category: Text, Web, JSON
abi: 0bddb8c122a0181e324f08c1b045cf5c
exposed: True
exposed-modules:
    Data.Aeson Data.Aeson.Encode Data.Aeson.Encoding
    Data.Aeson.Encoding.Internal Data.Aeson.Internal
    Data.Aeson.Internal.Time Data.Aeson.Parser
    Data.Aeson.Parser.Internal Data.Aeson.TH Data.Aeson.Text
    Data.Aeson.Types
hidden-modules: Data.Aeson.Compat Data.Aeson.Encoding.Builder
                Data.Aeson.Internal.Functions Data.Aeson.Parser.Unescape
                Data.Aeson.Parser.Time Data.Aeson.Types.FromJSON
                Data.Aeson.Types.Generic Data.Aeson.Types.ToJSON
                Data.Aeson.Types.Class Data.Aeson.Types.Internal
                Data.Attoparsec.Time Data.Attoparsec.Time.Internal
                Data.Aeson.Parser.UnescapePure
import-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-1.4.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-1.4.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/aeson-1.4.0.0
hs-libraries: HSaeson-1.4.0.0-LGp6kTtgO3W1vagljwPVLq
depends:
    attoparsec-0.13.2.2-66ub406fEYL5HI27KdshEC base-4.11.1.0
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ containers-0.5.11.0
    deepseq-1.4.3.0 dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD
    ghc-prim-0.5.2.0 hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO template-haskell-2.13.0.0
    text-1.2.3.0 th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88
    time-1.8.0.2 time-locale-compat-0.1.1.5-DDznVvFVEsmlk0WqJppPg
    unordered-containers-0.2.9.0-FkHC8tkjGhFEq6gcD4EsVo
    uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq bytestring-0.10.8.2
abi-depends: attoparsec-0.13.2.2-66ub406fEYL5HI27KdshEC=c6a831664a8826b2c70f720ac226f7d1
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=fc280138c1e1b70cf939493d29d4c902
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=d8185cdeb1f72c3606ef0c9fb78dc6d0
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=303b2de9b3dc2b2e86b6ff0f8de41846
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             time-locale-compat-0.1.1.5-DDznVvFVEsmlk0WqJppPg=0dc91a1ae9a857b8c5071d88d21ad3c6
             unordered-containers-0.2.9.0-FkHC8tkjGhFEq6gcD4EsVo=64a561e4e9a96e6da50de53181f89cb1
             uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71=b4d53b96ebd09e78eeddd19077455aea
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
haddock-interfaces: /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html: /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
